<?php
/**
 * @file
 * Contains \Drupal\spectra\Entity\SpectraAction.
 */

namespace Drupal\spectra\Entity;

use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\user\UserInterface;
use Drupal\spectra\Controller\SpectraController;
use Drupal\Core\Entity\EntityChangedTrait;

/**
 * Defines the SpectraAction entity.
 *
 * @ingroup spectra
 *
 *
 * @ContentEntityType(
 * id = "spectra_action",
 * label = @Translation("Spectra Action"),
 * handlers = {
 *   "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *   "list_builder" = "Drupal\spectra\Entity\Controller\SpectraActionListBuilder",
 *   "views_data" = "Drupal\spectra\Entity\Views\SpectraActionViewsData",
 *   "form" = {
 *     "add" = "Drupal\spectra\Form\SpectraActionForm",
 *     "edit" = "Drupal\spectra\Form\SpectraActionForm",
 *     "delete" = "Drupal\spectra\Form\SpectraActionDeleteForm",
 *   },
 *   "access" = "Drupal\spectra\SpectraActionAccessControlHandler",
 * },
 * base_table = "spectra_action",
 * admin_permission = "administer spectra_action entity",
 * fieldable = TRUE,
 * entity_keys = {
 *   "id" = "action_id",
 *   "uuid" = "uuid",
 *   "label" = "action_name",
 * },
 * links = {
 *   "canonical" = "/spectra_action/{spectra_action}",
 *   "edit-form" = "/spectra_action/{spectra_action}/edit",
 *   "delete-form" = "/spectra_action/{spectra_action}/delete",
 *   "collection" = "/spectra_action/list"
 * },
 * field_ui_base_route = "spectra.spectra_action_settings",
 * )
 */
class SpectraAction extends ContentEntityBase {

  use EntityChangedTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSpectraEntityType($type = 'machine_name') {
    switch ($type) {
      case 'class_name':
        return 'SpectraAction';
        break;
      case 'short':
        return 'action';
        break;
      case 'machine_name':
      default:
        return 'spectra_action';
    }
  }

  /**
   * {@inheritdoc}
   */
  public function getCreatedTime() {
    return $this->get('created')->value;
  }

  /**
   * {@inheritdoc}
   *
   * Define the field properties here.
   *
   * Field name, type and size determine the table structure.
   *
   * In addition, we can define how the field and its content can be manipulated
   * in the GUI. The behaviour of the widgets used can be determined here.
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {

    // Standard field, used as unique if primary index.
    $fields['action_id'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('ID'))
      ->setDescription(t('The ID of the SpectraAction entity.'))
      ->setReadOnly(TRUE);

    // Standard field, unique outside of the scope of the current project.
    $fields['uuid'] = BaseFieldDefinition::create('uuid')
      ->setLabel(t('UUID'))
      ->setDescription(t('The UUID of the SpectraAction entity.'))
      ->setReadOnly(TRUE);

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setDescription(t('The time that the entity was created.'));

    $fields['changed'] = BaseFieldDefinition::create('changed')
      ->setLabel(t('Changed'))
      ->setDescription(t('The time that the entity was created.'));

    $fields['action_name'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Name'))
      ->setDescription(t('Name'))
      ->setSettings(array(
        'default_value' => '',
        'max_length' => 255,
        'text_processing' => 0,
      ))
      ->setDisplayOptions('view', array(
        'label' => 'above',
        'type' => 'string',
        'weight' => -4,
      ))
      ->setDisplayOptions('form', array(
        'type' => 'string_textfield',
        'weight' => -4,
      ))
      ->setRequired(TRUE)
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['action_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Action Type'))
      ->setDescription(t('Used for determining the correct plugin to call, and for indexing.'))
      ->setSettings(array(
        'default_value' => 'default',
        'max_length' => 255,
        'text_processing' => 0,
      ))
      ->setDisplayOptions('view', array(
        'label' => 'above',
        'type' => 'string',
        'weight' => -4,
      ))
      ->setDisplayOptions('form', array(
        'type' => 'string_textfield',
        'weight' => -4,
      ))
      ->setRequired(TRUE)
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['action_description'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Description'))
      ->setDescription(t('Short description of Item'))
      ->setSettings(array(
        'default_value' => '',
        'max_length' => 1023,
        'text_processing' => 0,
      ))
      ->setDisplayOptions('view', array(
        'label' => 'above',
        'type' => 'string',
        'weight' => -4,
      ))
      ->setDisplayOptions('form', array(
        'type' => 'string_textfield',
        'weight' => -4,
      ))
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayConfigurable('view', TRUE);

    $fields['action_data'] = BaseFieldDefinition::create('jsonb')
      ->setLabel(t('Additional Data'))
      ->setDescription(t('Additional data to associate with this action.'));

    return $fields;
  }

}